@@ -385,14 +385,14 @@ namespace xt
     template <class O>
     inline auto xgenerator<F, R, S>::reshape(O&& shape) const &
     {
-        return reshape_view(*this, compute_shape(shape, std::is_signed<typename std::decay_t<O>::value_type>()));
+        return reshape_view(*this, compute_shape(shape, xtl::is_signed<typename std::decay_t<O>::value_type>()));
     }
 
     template <class F, class R, class S>
     template <class O>
     inline auto xgenerator<F, R, S>::reshape(O&& shape) &&
     {
-        return reshape_view(std::move(*this), compute_shape(shape, std::is_signed<typename std::decay_t<O>::value_type>()));
+        return reshape_view(std::move(*this), compute_shape(shape, xtl::is_signed<typename std::decay_t<O>::value_type>()));
     }
 
     template <class F, class R, class S>
@@ -454,7 +454,7 @@ namespace xt
         using sh_type = xt::dynamic_shape<T>;
         sh_type sh = xtl::make_sequence<sh_type>(shape.size());
         std::copy(shape.begin(), shape.end(), sh.begin());
-        return compute_shape(std::move(sh), std::is_signed<T>());
+        return compute_shape(std::move(sh), xtl::is_signed<T>());
     }
 
     template <class F, class R, class S>
