@@ -44,9 +44,6 @@ namespace xt
         zarray() = default;
         ~zarray() = default;
 
-        template <class E>
-        zarray(E&& e);
-
         zarray(implementation_ptr&& impl);
         zarray& operator=(implementation_ptr&& impl);
 
@@ -56,6 +53,15 @@ namespace xt
         zarray(zarray&& rhs);
         zarray& operator=(zarray&& rhs);
 
+        template <class E>
+        zarray(const xexpression<E>& e);
+
+        template <class E>
+        zarray(xexpression<E>& e);
+
+        template <class E>
+        zarray(xexpression<E>&& e);
+        
         template <class E>
         zarray& operator=(const xexpression<E>&);
 
@@ -70,6 +76,8 @@ namespace xt
         template <class T>
         const xarray<T>& get_array() const;
 
+        const zchunked_array& as_chunked_array() const;
+
     private:
 
         template <class E>
@@ -97,12 +105,6 @@ namespace xt
         p_impl = nullptr;
         semantic_base::assign(e);
     }
-    
-    template <class E>
-    inline zarray::zarray(E&& e)
-    {
-        init_implementation(std::forward<E>(e), extension::get_expression_tag_t<std::decay_t<E>>());
-    }
 
     inline zarray::zarray(implementation_ptr&& impl)
         : p_impl(std::move(impl))
@@ -132,6 +134,24 @@ namespace xt
     {
     }
 
+    template <class E>
+    inline zarray::zarray(const xexpression<E>& e)
+    {
+        init_implementation(e.derived_cast(), extension::get_expression_tag_t<std::decay_t<E>>());
+    }
+
+    template <class E>
+    inline zarray::zarray(xexpression<E>& e)
+    {
+        init_implementation(e.derived_cast(), extension::get_expression_tag_t<std::decay_t<E>>());
+    }
+
+    template <class E>
+    inline zarray::zarray(xexpression<E>&& e)
+    {
+        init_implementation(std::move(e).derived_cast(), extension::get_expression_tag_t<std::decay_t<E>>());
+    }
+
     inline zarray& zarray::operator=(zarray&& rhs)
     {
         swap(rhs);
@@ -170,6 +190,11 @@ namespace xt
     {
         return dynamic_cast<const ztyped_array<T>*>(p_impl.get())->get_array();
     }
+
+    inline const zchunked_array& zarray::as_chunked_array() const
+    {
+        return dynamic_cast<const zchunked_array&>(*(p_impl.get()));
+    }
 }
 
 #endif
